/* error.h
 * Copyright (C) 2004, 2005 Sylvain Cresto <sylvain.cresto@tiscali.fr>
 *
 * This file is part of graveman!
 *
 * graveman! is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or
 * (at your option) any later version.
 * 
 * graveman! is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA. 
 * 
 * URL: http://www.nongnu.org/graveman/
 *
 */

#define GRAVEMAN_ERROR graveman_error_quark()

#define _ERR_TEST   10
#define _ERR_NO_CD  11
#define _ERR_BUF_EMPTY 12
#define _ERR_INAPPROPRIATE_DATA 13
#define _ERR_INAPPROPRIATE_MODE 14
#define _ERR_BAD_RECORDER 15
#define _ERR_READCD 16
#define _ERR_MKISOFS 17
#define _ERR_INCOMPATIBLE_MEDIUM 18
#define _ERR_CANNOT_BLANK 19
#define _ERR_SOX 20
#define _ERR_ALREADY_FORMAT 21
#define _ERR_CONFIGURATION 22
#define _ERR_UNKNOWN_ERROR 100

/*
 * vim:et:ts=8:sts=2:sw=2
 */
